package com.ruoyi.abuwx.service.impl;

import com.ruoyi.abuwx.domain.InfoOperationRecord;
import com.ruoyi.abuwx.mapper.InfoOperationRecordMapper;
import com.ruoyi.abuwx.service.IInfoOperationRecordService;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 资讯信息操作记录Service业务层处理
 * 
 * @author lujie
 * @date 2025-01-10
 */
@Service
public class InfoOperationRecordServiceImpl implements IInfoOperationRecordService 
{
    @Autowired
    private InfoOperationRecordMapper infoOperationRecordMapper;

    /**
     * 查询资讯信息操作记录
     * 
     * @param id 资讯信息操作记录主键
     * @return 资讯信息操作记录
     */
    @Override
    public InfoOperationRecord selectInfoOperationRecordById(Long id)
    {
        return infoOperationRecordMapper.selectInfoOperationRecordById(id);
    }

    /**
     * 查询资讯信息操作记录列表
     * 
     * @param infoOperationRecord 资讯信息操作记录
     * @return 资讯信息操作记录
     */
    @Override
    public List<InfoOperationRecord> selectInfoOperationRecordList(InfoOperationRecord infoOperationRecord)
    {
        return infoOperationRecordMapper.selectInfoOperationRecordList(infoOperationRecord);
    }

    /**
     * 新增资讯信息操作记录
     * 
     * @param infoOperationRecord 资讯信息操作记录
     * @return 结果
     */
    @Override
    public int insertInfoOperationRecord(InfoOperationRecord infoOperationRecord)
    {
        infoOperationRecord.setCreateTime(DateUtils.getNowDate());
        return infoOperationRecordMapper.insertInfoOperationRecord(infoOperationRecord);
    }

    /**
     * 修改资讯信息操作记录
     * 
     * @param infoOperationRecord 资讯信息操作记录
     * @return 结果
     */
    @Override
    public int updateInfoOperationRecord(InfoOperationRecord infoOperationRecord)
    {
        infoOperationRecord.setUpdateTime(DateUtils.getNowDate());
        return infoOperationRecordMapper.updateInfoOperationRecord(infoOperationRecord);
    }

    /**
     * 批量删除资讯信息操作记录
     * 
     * @param ids 需要删除的资讯信息操作记录主键
     * @return 结果
     */
    @Override
    public int deleteInfoOperationRecordByIds(Long[] ids)
    {
        return infoOperationRecordMapper.deleteInfoOperationRecordByIds(ids);
    }

    /**
     * 删除资讯信息操作记录信息
     * 
     * @param id 资讯信息操作记录主键
     * @return 结果
     */
    @Override
    public int deleteInfoOperationRecordById(Long id)
    {
        return infoOperationRecordMapper.deleteInfoOperationRecordById(id);
    }
}
