package com.ruoyi.abuwx.service.impl;

import com.ruoyi.abuwx.domain.UserFavorite;
import com.ruoyi.abuwx.mapper.UserFavoriteMapper;
import com.ruoyi.abuwx.service.IUserFavoriteService;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户收藏记录Service业务层处理
 *
 * @author lujie
 * @date 2025-02-05
 */
@Service
public class UserFavoriteServiceImpl implements IUserFavoriteService
{
    @Autowired
    private UserFavoriteMapper userFavoriteMapper;

    /**
     * 查询用户收藏记录
     *
     * @param id 用户收藏记录主键
     * @return 用户收藏记录
     */
    @Override
    public UserFavorite selectUserFavoriteById(Long id)
    {
        return userFavoriteMapper.selectUserFavoriteById(id);
    }

    /**
     * 查询用户收藏记录列表
     *
     * @param userFavorite 用户收藏记录
     * @return 用户收藏记录
     */
    @Override
    public List<UserFavorite> selectUserFavoriteList(UserFavorite userFavorite)
    {
        return userFavoriteMapper.selectUserFavoriteList(userFavorite);
    }

    /**
     * 新增用户收藏记录
     *
     * @param userFavorite 用户收藏记录
     * @return 结果
     */
    @Override
    public int insertUserFavorite(UserFavorite userFavorite)
    {
        userFavorite.setCreateTime(DateUtils.getNowDate());
        return userFavoriteMapper.insertUserFavorite(userFavorite);
    }

    /**
     * 修改用户收藏记录
     *
     * @param userFavorite 用户收藏记录
     * @return 结果
     */
    @Override
    public int updateUserFavorite(UserFavorite userFavorite)
    {
        userFavorite.setUpdateTime(DateUtils.getNowDate());
        return userFavoriteMapper.updateUserFavorite(userFavorite);
    }

    /**
     * 批量删除用户收藏记录
     *
     * @param ids 需要删除的用户收藏记录主键
     * @return 结果
     */
    @Override
    public int deleteUserFavoriteByIds(Long[] ids)
    {
        return userFavoriteMapper.deleteUserFavoriteByIds(ids);
    }

    /**
     * 删除用户收藏记录信息
     *
     * @param id 用户收藏记录主键
     * @return 结果
     */
    @Override
    public int deleteUserFavoriteById(Long id)
    {
        return userFavoriteMapper.deleteUserFavoriteById(id);
    }

    @Override
    public int unFavorite(Long userId, Long contentType, Long contentId) {
        return userFavoriteMapper.unFavorite(userId,contentType,contentId);
    }

    @Override
    public int favoriteContent(Long userId, Long contentType, Long contentId) {
        UserFavorite userFavorite = new UserFavorite();
        userFavorite.setUserId(userId);
        userFavorite.setContentType(contentType);
        userFavorite.setContentId(contentId);
        userFavorite.setCreateTime(DateUtils.getNowDate());
        return userFavoriteMapper.insertUserFavorite(userFavorite);
    }
}
